@@ -6,6 +6,8 @@ from .fields import FormFieldList
 from .fields import EnumField
 from .fields import DictionaryField
 from .fields import AnyField
+from .fields import FileField
+from .fields import ImageField
 from .forms import Form
 from .version import __version__
 
@@ -18,6 +20,8 @@ __all__ = [
     'EnumField',
     'DictionaryField',
     'AnyField',
+    'FileField',
+    'ImageField',
     'Form',
     '__version__'
 ]
